@@ -1,12 +1,12 @@
 import argparse
-import json
-from urllib.request import urlopen
 import os
-import bs4
+
 from scraper import shelves
+from scraper import user
 
 
-def scrape_user(args):
+def scrape_user(args: argparse.Namespace):
+    user.get_user_info(args)
     shelves.get_all_shelves(args)
 
 
@@ -14,6 +14,9 @@ def main():
     parser = argparse.ArgumentParser()
     parser.add_argument("--user_id", type=str, required=True)
     parser.add_argument("--output_dir", type=str, default="goodreads-data")
+    parser.add_argument("--skip_user_info", type=bool, default=False)
+    parser.add_argument("--skip_shelves", type=bool, default=False)
+
     args = parser.parse_args()
 
     args.output_dir = (
